@@ -8,5 +8,8 @@ var structnl__object__ops =
     [ "oo_clone", "structnl__object__ops.html#ada92030f50d49c033007952393c8d9b2", null ],
     [ "oo_dump", "structnl__object__ops.html#a77baeae119f4b39551dc353c33225fcc", null ],
     [ "oo_compare", "structnl__object__ops.html#aeabb90e7882be2af2c6e92391cce9597", null ],
-    [ "oo_attrs2str", "structnl__object__ops.html#adbc8dbb9132673139035da7011920765", null ]
+    [ "oo_update", "structnl__object__ops.html#a730499b453da31889a9b0980f3bfffe3", null ],
+    [ "oo_keygen", "structnl__object__ops.html#a8da125195da7c9fef5111b20f7e2efd4", null ],
+    [ "oo_attrs2str", "structnl__object__ops.html#adbc8dbb9132673139035da7011920765", null ],
+    [ "oo_id_attrs_get", "structnl__object__ops.html#ae9ef923c723cfe3d943d581326f56e2d", null ]
 ];
\ No newline at end of file
